@@ -1,8 +1,8 @@
-"""
-Conftest module.
+"""Conftest module.
 
 This module contains pytest fixtures.
 """
+
 import os
 
 import pytest
