@@ -1,8 +1,9 @@
-"""
-Test Init module.
+# ruff: noqa: S106
+"""Test Init module.
 
 This module contains tests for project init.
 """
+
 import pytest
 
 from mokkari import api, exceptions, session
