@@ -1,11 +1,8 @@
-"""
-Test Role api.
+"""Test Role api.
 
 This module contains tests for Role objects.
 """
-import pytest
 
-from mokkari import exceptions, issue
 from mokkari.session import Session
 
 
@@ -18,9 +15,3 @@ def test_role_list(talker: Session) -> None:
     assert next(role_iter).name == "Assistant Editor"
     assert len(roles) == 11
     assert roles[1].name == "Consulting Editor"
-
-
-def test_bad_response_data() -> None:
-    """Test for a bad role response."""
-    with pytest.raises(exceptions.ApiError):
-        issue.RoleList({"results": {"name": 1}})
